@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,24 +14,31 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from files import ( process, checkUtils, readFile, listDirectory,readLinesFile, 
-                   getRunCommands, getProgPath )
-import sys,os
+from files import (process, checkUtils, readFile, listDirectory,
+                   getRunCommands, getProgPath)
+import sys
+import os
 import re
-import struct,fcntl,socket,math,ctypes
+import struct
+import fcntl
+import socket
+import math
+import ctypes
 from os import path
-import select, time
+import select
+import time
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_lib3',sys.modules[__name__])
+_ = lambda x: x
+setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 SYSFS_NET_PATH = "/sys/class/net"
 PROCFS_NET_PATH = "/proc/net/dev"
 
 # From linux/sockios.h
 SIOCGIFINDEX = 0x8933
-SIOCGIFFLAGS =  0x8913
-SIOCSIFFLAGS =  0x8914
+SIOCGIFFLAGS = 0x8913
+SIOCSIFFLAGS = 0x8914
 SIOCSIFHWADDR = 0x8924
 SIOCSIFADDR = 0x8916
 SIOCSIFNETMASK = 0x891C
@@ -49,43 +56,49 @@ IP_DIG = "[%s-9]|(?:1[0-9]|[1-9])[0-9]|2[0-4][0-9]|25[0-%s]"
 # ip net 0-32
 IP_NET_SUFFIX = "[0-9]|[12][0-9]|3[012]"
 # ip digs 1-254,0-254,0-255
-IP_DIGS = { 'dig1_254' : IP_DIG % (1,4), 'dig0_254' : IP_DIG % (0,4),
-           'dig0_255' : IP_DIG % (0,5), }
+IP_DIGS = {'dig1_254': IP_DIG % (1, 4), 'dig0_254': IP_DIG % (0, 4),
+           'dig0_255': IP_DIG % (0, 5), }
 # ip addr 10.0.0.12
-IP_ADDR = "(%(dig1_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)\.(%(dig1_254)s)"%\
-            IP_DIGS
-IP_MASK = "(%(dig0_255)s)\.(%(dig0_255)s)\.(%(dig0_255)s)\.(%(dig0_255)s)"%\
-            IP_DIGS
+IP_ADDR = "(%(dig1_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)\.(%(dig1_254)s)" % \
+          IP_DIGS
+IP_MASK = "(%(dig0_255)s)\.(%(dig0_255)s)\.(%(dig0_255)s)\.(%(dig0_255)s)" % \
+          IP_DIGS
 # ip addr for net 10.0.0.0
-IP_NET = "(%(dig1_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)"%\
-            IP_DIGS
+IP_NET = "(%(dig1_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)\.(%(dig0_254)s)" % \
+         IP_DIGS
 # ip and net 192.168.0.0/16
-IP_ADDR_NET = "(%(ipaddr)s)/((%(ipnet)s))"%{'ipaddr':IP_NET,
-                                            'ipnet':IP_NET_SUFFIX}
+IP_ADDR_NET = "(%(ipaddr)s)/((%(ipnet)s))" % {'ipaddr': IP_NET,
+                                              'ipnet': IP_NET_SUFFIX}
 
 reIp = re.compile("^{0}$".format(IP_ADDR))
 reNetSuffix = re.compile("^{0}$".format(IP_NET_SUFFIX))
 reNet = re.compile("^{0}$".format(IP_ADDR_NET))
 reMask = re.compile("^{0}$".format(IP_MASK))
 
+
 def checkIp(ip):
     """Check ip"""
     return reIp.match(ip)
 
+
 def checkNetSuffix(netSuffix):
     """Check net suffix"""
     return reNetSuffix.match(netSuffix)
 
+
 def checkNet(net):
     """Check net"""
     if not reNet.match(net):
         return False
-    ip,op,cidr = net.partition('/')
+    ip, op, cidr = net.partition('/')
     mask = strIpToIntIp(cidrToMask(int(cidr)))
-    return (strIpToIntIp(ip)&mask) == (strIpToIntIp(ip))
+    return (strIpToIntIp(ip) & mask) == (strIpToIntIp(ip))
+
+
+maskDigs = map(lambda x: str(x),
+               (0b10000000, 0b11000000, 0b11100000, 0b11110000,
+                0b11111000, 0b11111100, 0b11111110, 0b11111111))
 
-maskDigs = map(lambda x:str(x),(0b10000000,0b11000000,0b11100000,0b11110000,
-                                0b11111000,0b11111100,0b11111110,0b11111111))
 
 def checkMask(mask):
     """Check net"""
@@ -102,47 +115,51 @@ def checkMask(mask):
                 return False
     return True
 
+
 def getIpAndMask(interface="eth0"):
     """Get ip and mask from interface"""
-    ifconfig = process('/sbin/ifconfig',interface)
-    res = re.search(r"inet addr:(\S+)\s.*Mask:(\S+)",ifconfig.read(),re.S)
+    ifconfig = process('/sbin/ifconfig', interface)
+    res = re.search(r"inet addr:(\S+)\s.*Mask:(\S+)", ifconfig.read(), re.S)
     if res:
         return res.groups()
     else:
-        return ("","")
+        return "", ""
+
 
 def strIpToIntIp(addr):
     """Convert ip specified by string to integer"""
     addr = addr.split('.')
-    return ((int(addr[0])<<24)|
-           (int(addr[1])<<16)|
-           (int(addr[2])<<8)|
-           (int(addr[3])))
-    return reduce(lambda x,y:x+(int(y[1])<<(y[0]*8)),
-           enumerate(reversed(addr.split("."))),0)
+    return ((int(addr[0]) << 24) |
+            (int(addr[1]) << 16) |
+            (int(addr[2]) << 8) |
+            (int(addr[3])))
 
 def intIpToStrIp(addr):
     """Convert ip specified by integer to string"""
     return "{0}.{1}.{2}.{3}".format(
-            addr>>24,(addr>>16)&0xff,(addr>>8)&0xff,addr&0xff)
+        addr >> 24, (addr >> 16) & 0xff, (addr >> 8) & 0xff, addr & 0xff)
+
 
 def numMaskToCidr(netmask):
     """
     Convert integer mask to cidr
     """
     neg_net = ctypes.c_uint32(~netmask).value
-    return 32 - int(math.log(neg_net,2))-1 if neg_net else 32
+    return 32 - int(math.log(neg_net, 2)) - 1 if neg_net else 32
+
 
 def maskToCidr(mask):
     """Convert mask specified by str to net"""
     mask = strIpToIntIp(mask)
     return numMaskToCidr(mask)
 
+
 def cidrToMask(cidr):
     """Convert net to mask specified by str"""
-    return intIpToStrIp((2**cidr-1)<<(32-cidr))
+    return intIpToStrIp((2 ** cidr - 1) << (32 - cidr))
 
-def getIpNet(ip,mask=None,cidr=None):
+
+def getIpNet(ip, mask=None, cidr=None):
     """Get net (xx.xx.xx.xx/xx) by ip address and mask"""
     ip = strIpToIntIp(ip)
     if not mask is None:
@@ -151,64 +168,72 @@ def getIpNet(ip,mask=None,cidr=None):
         net = int(cidr)
         mask = cidrToMask(net)
     mask = strIpToIntIp(mask)
-    return "{ip}/{net}".format(ip=intIpToStrIp(ip&mask),
+    return "{ip}/{net}".format(ip=intIpToStrIp(ip & mask),
                                net=net)
 
-def isIpInNet(checkip,*ipnets):
+
+def isIpInNet(checkip, *ipnets):
     """Check is ip in specified nets"""
-    return map(lambda x:x[0],
-          filter(lambda x:strIpToIntIp(checkip)&x[2] == strIpToIntIp(x[1])&x[2],
-          map(lambda x:(x[0],x[1][0],strIpToIntIp(cidrToMask(int(x[1][1])))),
-          map(lambda x:(x,x.partition('/')[0::2]),
-          ipnets))))
+    return map(lambda x: x[0],
+               filter(lambda x: strIpToIntIp(checkip) & x[2] == strIpToIntIp(
+                   x[1]) & x[2],
+                      map(lambda x: (
+                          x[0], x[1][0],
+                          strIpToIntIp(cidrToMask(int(x[1][1])))),
+                          map(lambda x: (x, x.partition('/')[0::2]),
+                              ipnets))))
+
 
 def isDhcpIp(interface="eth0"):
     """Get ip by dhcp or static"""
     # dhclients (dhcpcd, dhclient (dhcp), udhcpc (busybox)
     commands = getRunCommands()
-    dhcpProgs = ("dhcpcd","dhclient","udhcpc")
-    if filter(lambda x:interface in x and any(prog in x for prog in dhcpProgs),
-       commands):
+    dhcpProgs = ("dhcpcd", "dhclient", "udhcpc")
+    if filter(lambda x: interface in x and any(prog in x for prog in dhcpProgs),
+              commands):
         return True
     else:
         # если запущен демон dhcpcd
-        if filter(lambda x:"dhcpcd\x00-q" in x,commands):
+        if filter(lambda x: "dhcpcd\x00-q" in x, commands):
             curIp = getIp(interface)
             dhcpcd = getProgPath('/sbin/dhcpcd')
             leaseIp = \
-                map(lambda x:x.group(1),
-                filter(None,
-                map(re.compile('^ip_address=(.*)$').search,
-                process(dhcpcd,'-U',interface))))
+                map(lambda x: x.group(1),
+                    filter(None,
+                           map(re.compile('^ip_address=(.*)$').search,
+                               process(dhcpcd, '-U', interface))))
             if not curIp or leaseIp and leaseIp[0] == curIp:
                 return True
         return False
 
-def getRouteTable(onlyIface=[]):
+
+def getRouteTable(onlyIface=()):
     """Get route table, exclude specifed iface"""
     ipProg = checkUtils('/sbin/ip')
-    routes = process(ipProg,"route")
+    routes = process(ipProg, "route")
     if onlyIface:
-        filterRe = re.compile("|".join(map(lambda x:r"dev %s"%x,onlyIface)))
-        routes = filter(filterRe.search,routes)
+        filterRe = re.compile("|".join(map(lambda x: r"dev %s" % x, onlyIface)))
+        routes = filter(filterRe.search, routes)
     for line in routes:
-        network,op,line = line.partition(" ")
-        routeParams = map(lambda x:x.strip(),line.split())
+        network, op, line = line.partition(" ")
+        routeParams = map(lambda x: x.strip(), line.split())
         # (network,{'via':value,'dev':value})
         if network:
-            yield (network,dict(zip(routeParams[0::2],routeParams[1::2])))
+            yield (network, dict(zip(routeParams[0::2], routeParams[1::2])))
+
 
 def getInterfaces():
     """
     Get available interfaces (discard which hasn't device)
     """
     return sorted(
-           filter(lambda x:path.exists(path.join(SYSFS_NET_PATH,x,"device")),
-           listDirectory(SYSFS_NET_PATH)))
+        filter(lambda x: path.exists(path.join(SYSFS_NET_PATH, x, "device")),
+               listDirectory(SYSFS_NET_PATH)))
+
 
 def getIp(iface):
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00'*14)
+    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFADDR, ifreq)
     except IOError:
@@ -218,9 +243,10 @@ def getIp(iface):
     ip = struct.unpack('16sH2x4s8x', res)[2]
     return socket.inet_ntoa(ip)
 
+
 def getPlugged(iface):
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00'*14)
+    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFFLAGS, ifreq)
     except IOError:
@@ -229,12 +255,13 @@ def getPlugged(iface):
         sockfd.close()
     return bool(struct.unpack('16sH2x4s8x', res)[1] & IFF_RUNNING)
 
+
 def getMask(iface):
     """
     Get mask for interface
     """
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00'*14)
+    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFNETMASK, ifreq)
     except IOError:
@@ -244,12 +271,13 @@ def getMask(iface):
     netmask = socket.ntohl(struct.unpack('16sH2xI8x', res)[2])
     return numMaskToCidr(netmask)
 
+
 def getMac(iface):
     """
     Get mac for interface
     """
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_UNIX, '\x00'*14)
+    ifreq = struct.pack('16sH14s', iface, socket.AF_UNIX, '\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFHWADDR, ifreq)
     except IOError:
@@ -259,71 +287,74 @@ def getMac(iface):
     sockfd.close()
     return ":".join(['%02X' % i for i in mac])
 
+
 def getOperState(iface):
     """
     Get interface state up or down
     """
-    if readFile("/sys/class/net/%s/operstate"%iface) == "down":
+    if readFile("/sys/class/net/%s/operstate" % iface) == "down":
         return "down"
     return "up"
 
-def isOpenPort(ip,port):
+
+def isOpenPort(ip, port):
     """
     Test if an [ip:port] is open
     """
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     try:
-        s.connect((ip,int(port)))
+        s.connect((ip, int(port)))
         s.shutdown(2)
         return True
-    except:
+    except Exception:
         return False
 
+
 class IPError(Exception):
     """Error received on work with ip"""
     pass
-  
-class Pinger:
-    # ICMP parameters
-    ICMP_ECHO       =    8 # Echo request (per RFC792)
-    ICMP_MAX_RECV   = 2048 # Max size of incoming buffer
 
-    def checksum(self,source_string):
+
+class Pinger(object):
+    # ICMP parameters
+    ICMP_ECHO = 8  # Echo request (per RFC792)
+    ICMP_MAX_RECV = 2048  # Max size of incoming buffer
+
+    def checksum(self, source_string):
         """
         A port of the functionality of in_cksum() from ping.c
         Ideally this would act on the string as a series of 16-bit ints (host
         packed), but this works.
         Network data is big-endian, hosts are typically little-endian
         """
-        countTo = (int(len(source_string)/2))*2
+        countTo = (int(len(source_string) / 2)) * 2
         sum = 0
         count = 0
 
         # Handle bytes in pairs (decoding as short ints)
-        loByte = 0
-        hiByte = 0
         while count < countTo:
-            if (sys.byteorder == "little"):
+            if sys.byteorder == "little":
                 loByte = ord(source_string[count])
                 hiByte = ord(source_string[count + 1])
             else:
                 loByte = ord(source_string[count + 1])
                 hiByte = ord(source_string[count])
-            sum = sum + ((hiByte) * 256 + (loByte))
+            sum += hiByte * 256 + loByte
             count += 2
 
         # Handle last byte if applicable (odd-number of bytes)
         # Endianness should be irrelevant in this case
-        if countTo < len(source_string): # Check for odd length
-            loByte = ord(source_string[len(source_string)-1])
+        if countTo < len(source_string):  # Check for odd length
+            loByte = ord(source_string[len(source_string) - 1])
             sum += loByte
 
-        sum &= 0xffffffff #Truncate sum to 32 bits (a variance from ping.c,which
-                          #uses signed ints, but overflow is unlikely in ping)
+        # Truncate sum to 32 bits (a variance from ping.c,which
+        sum &= 0xffffffff
+        # uses signed ints, but overflow is unlikely in ping)
 
-        sum = (sum >> 16) + (sum & 0xffff)    # Add high 16 bits to low 16 bits
-        sum += (sum >> 16)                    # Add carry from above (if any)
-        answer = ~sum & 0xffff              # Invert and truncate to 16 bits
+        sum = (sum >> 16) + (sum & 0xffff)  # Add high 16 bits to low 16 bits
+        sum += (sum >> 16)  # Add carry from above (if any)
+        answer = ~sum & 0xffff  # Invert and truncate to 16 bits
         answer = socket.htons(answer)
 
         return answer
@@ -334,7 +365,7 @@ class Pinger:
         """
         delay = None
 
-        try: # One could use UDP here, but it's obscure
+        try:  # One could use UDP here, but it's obscure
             mySocket = socket.socket(socket.AF_INET, socket.SOCK_RAW,
                                      socket.getprotobyname("icmp"))
         except socket.error as e:
@@ -343,29 +374,29 @@ class Pinger:
         my_ID = os.getpid() & 0xFFFF
 
         sentTime = self.send_one_ping(mySocket, destIP, my_ID, 0,
-                                 numDataBytes)
-        if sentTime == None:
+                                      numDataBytes)
+        if sentTime is None:
             mySocket.close()
             return delay
 
         recvTime, dataSize, iphSrcIP, icmpSeqNumber, iphTTL = \
-                            self.receive_one_ping(mySocket, my_ID, timeout)
+            self.receive_one_ping(mySocket, my_ID, timeout)
 
         mySocket.close()
 
         if recvTime:
-            delay = (recvTime-sentTime)*1000
-            return (dataSize,socket.inet_ntoa(struct.pack("!I", iphSrcIP)),
-                    iphTTL,delay)
+            delay = (recvTime - sentTime) * 1000
+            return (dataSize, socket.inet_ntoa(struct.pack("!I", iphSrcIP)),
+                    iphTTL, delay)
         else:
             raise IPError(_("Request timed out"))
 
-    def send_one_ping(self,mySocket, destIP, myID, mySeqNumber, numDataBytes):
+    def send_one_ping(self, mySocket, destIP, myID, mySeqNumber, numDataBytes):
         """
         Send one ping to the given >destIP<.
         """
         try:
-            destIP  =  socket.gethostbyname(destIP)
+            destIP = socket.gethostbyname(destIP)
         except socket.gaierror as e:
             raise IPError(e.strerror)
 
@@ -379,7 +410,7 @@ class Pinger:
 
         padBytes = []
         startVal = 0x42
-        for i in range(startVal, startVal + (numDataBytes)):
+        for i in range(startVal, startVal + numDataBytes):
             padBytes += [(i & 0xff)]  # Keep chars in the 0-255 range
         data = bytes(padBytes)
 
@@ -409,13 +440,13 @@ class Pinger:
         """
         Receive the ping from the socket. Timeout = in ms
         """
-        timeLeft = timeout/1000.0
+        timeLeft = timeout / 1000.0
 
-        while True: # Loop while waiting for packet or timeout
+        while True:  # Loop while waiting for packet or timeout
             startedSelect = time.time()
             whatReady = select.select([mySocket], [], [], timeLeft)
             howLongInSelect = (time.time() - startedSelect)
-            if whatReady[0] == []: # Timeout
+            if isinstance(whatReady[0], list) and not whatReady[0]:  # Timeout
                 return None, 0, 0, 0, 0
 
             timeReceived = time.time()
@@ -435,7 +466,7 @@ class Pinger:
                 "!BBHHH", icmpHeader
             )
 
-            if icmpPacketID == myID: # Our packet
+            if icmpPacketID == myID:  # Our packet
                 dataSize = len(recPacket) - 28
                 return timeReceived, dataSize, iphSrcIP, icmpSeqNumber, iphTTL
 
